@@ -30,6 +30,8 @@
 #include <eel/eel-string.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
+#include <libnautilus-private/nautilus-thumbnails.h>
+#include <libnautilus-private/nautilus-desktop-icon-file.h>
 
 #include "fm-icon-container.h"
 
@@ -85,19 +87,12 @@ fm_icon_container_start_monitor_top_left (NautilusIconContainer *container,
 					  gconstpointer          client)
 {
 	NautilusFile *file;
-	GList *attributes;
 
 	file = (NautilusFile *) data;
 
 	g_assert (NAUTILUS_IS_FILE (file));
 
-
-	attributes = NULL;
-	attributes = g_list_prepend (attributes,
-				     NAUTILUS_FILE_ATTRIBUTE_TOP_LEFT_TEXT);
-
-	nautilus_file_monitor_add (file, client, attributes);
-        g_list_free (attributes);
+	nautilus_file_monitor_add (file, client, NAUTILUS_FILE_ATTRIBUTE_TOP_LEFT_TEXT);
 }
 
 static void
@@ -114,6 +109,24 @@ fm_icon_container_stop_monitor_top_left (NautilusIconContainer *container,
 	nautilus_file_monitor_remove (file, client);
 }
 
+static void
+fm_icon_container_prioritize_thumbnailing (NautilusIconContainer *container,
+					   NautilusIconData      *data)
+{
+	NautilusFile *file;
+	char *uri;
+
+	file = (NautilusFile *) data;
+
+	g_assert (NAUTILUS_IS_FILE (file));
+
+	if (nautilus_file_is_thumbnailing (file)) {
+		uri = nautilus_file_get_uri (file);
+		nautilus_thumbnail_prioritize (uri);
+		g_free (uri);
+	}
+}
+
 
 /*
  * Get the preference for which caption text should appear
@@ -236,6 +249,13 @@ fm_icon_container_get_icon_text (NautilusIconContainer *container,
 		*editable_text = nautilus_file_get_display_name (file);
 	}
 
+	if (NAUTILUS_IS_DESKTOP_ICON_FILE (file)) {
+		/* Don't show the normal extra information for desktop icons, it doesn't
+		 * make sense. */
+ 		*additional_text = NULL;
+		return;
+	}
+	
 	/* Handle link files specially. */
 	if (nautilus_file_is_nautilus_link (file)) {
 		/* FIXME bugzilla.gnome.org 42531: Does sync. I/O and works only locally. */
@@ -306,34 +326,30 @@ typedef enum {
 static SortCategory
 get_sort_category (NautilusFile *file)
 {
-	char *uri;
+	NautilusDesktopLink *link;
 	SortCategory category;
 
-	if (!nautilus_file_is_nautilus_link (file)) {
-		category = SORT_OTHER;
-	} else {
-		if (!nautilus_file_is_local (file))
-			return SORT_OTHER;
-
-		uri = nautilus_file_get_uri (file);
+	if (NAUTILUS_IS_DESKTOP_ICON_FILE (file)) {
+		link = nautilus_desktop_icon_file_get_link (NAUTILUS_DESKTOP_ICON_FILE (file));
 		
-		switch (nautilus_link_local_get_link_type (uri, NULL)) {
-		case NAUTILUS_LINK_HOME:
+		switch (nautilus_desktop_link_get_link_type (link)) {
+		case NAUTILUS_DESKTOP_LINK_HOME:
 			category = SORT_HOME_LINK;
 			break;
-		case NAUTILUS_LINK_MOUNT:
+		case NAUTILUS_DESKTOP_LINK_VOLUME:
 			category = SORT_MOUNT_LINK;
 			break;
-		case NAUTILUS_LINK_TRASH:
+		case NAUTILUS_DESKTOP_LINK_TRASH:
 			category = SORT_TRASH_LINK;
 			break;
 		default:
 			category = SORT_OTHER;
 			break;
 		}
-		
-		g_free (uri);
-	}
+		g_object_unref (link);
+	} else {
+		category = SORT_OTHER;
+	} 
 	
 	return category;
 }
@@ -427,6 +443,7 @@ fm_icon_container_class_init (FMIconContainerClass *klass)
 	ic_class->get_icon_images = fm_icon_container_get_icon_images;
 	ic_class->start_monitor_top_left = fm_icon_container_start_monitor_top_left;
 	ic_class->stop_monitor_top_left = fm_icon_container_stop_monitor_top_left;
+	ic_class->prioritize_thumbnailing = fm_icon_container_prioritize_thumbnailing;
 
 	ic_class->compare_icons = fm_icon_container_compare_icons;
 	ic_class->compare_icons_by_name = fm_icon_container_compare_icons_by_name;
